@@ -1,8 +1,8 @@
 import argparse
 import os
 import subprocess
-import tempfile
 import sys
+import tempfile
 import time
 
 import requests
@@ -71,11 +71,11 @@ def main(args=None, in_jupyter=False):
         """.strip(),
     )
     argparser.add_argument(
-        '--github-app-url',
-        default=os.environ.get('GH_SCOPED_CREDS_APP_URL'),
+        "--github-app-url",
+        default=os.environ.get("GH_SCOPED_CREDS_APP_URL"),
         help="""
         URL where users can install & grant repo access to the app
-        """.strip()
+        """.strip(),
     )
 
     args = argparser.parse_args(args)
@@ -90,7 +90,7 @@ def main(args=None, in_jupyter=False):
     access_token, expires_in = do_authenticate_device_flow(args.client_id, in_jupyter)
 
     # Create a secure temporary file and write the creds to it
-    with tempfile.NamedTemporaryFile(delete=False, mode='w+') as f:
+    with tempfile.NamedTemporaryFile(delete=False, mode="w+") as f:
         f.write(f"https://x-access-token:{access_token}@github.com\n")
         f.flush()
 
@@ -117,7 +117,11 @@ def main(args=None, in_jupyter=False):
         print(success)
 
     if args.github_app_url:
-        print(f'Visit {args.github_app_url} to manage list of repositories you can push to from this location')
+        print(
+            f"Visit {args.github_app_url} to manage list of repositories you can push to from this location"
+        )
+    # This only sets up credentials for https, not for ssh!
+    print('Tip: Use https:// URLs to clone and push to repos, not ssh URLs!')
 
 
 try:
